#ifdef	__GNUC__
#    define alloca(x) __builtin_alloca (x)
#else
#ifdef HAVE_ALLOCA_H
#       include <alloca.h>
#else
#ifdef __STDC__
typedef void	*pointer;		/* generic pointer type */
pointer alloca (unsigned);		/* returns pointer to storage */
#else
typedef char	*pointer;		/* generic pointer type */
pointer alloca ();			/* returns pointer to storage */
#endif /* __STDC__ */
#endif
#endif
